@@ -122,10 +122,6 @@
 //! It's also possible to share senders and receivers by reference:
 //!
 //! ```
-//! # extern crate crossbeam_channel;
-//! # extern crate crossbeam_utils;
-//! # fn main() {
-//! use std::thread;
 //! use crossbeam_channel::bounded;
 //! use crossbeam_utils::thread::scope;
 //!
@@ -142,7 +138,6 @@
 //!     s.send(1).unwrap();
 //!     r.recv().unwrap();
 //! }).unwrap();
-//! # }
 //! ```
 //!
 //! # Disconnection
@@ -271,12 +266,9 @@
 //! An example of receiving a message from two channels:
 //!
 //! ```
-//! # #[macro_use]
-//! # extern crate crossbeam_channel;
-//! # fn main() {
 //! use std::thread;
 //! use std::time::Duration;
-//! use crossbeam_channel::unbounded;
+//! use crossbeam_channel::{select, unbounded};
 //!
 //! let (s1, r1) = unbounded();
 //! let (s2, r2) = unbounded();
@@ -290,7 +282,6 @@
 //!     recv(r2) -> msg => assert_eq!(msg, Ok(20)),
 //!     default(Duration::from_secs(1)) => println!("timed out"),
 //! }
-//! # }
 //! ```
 //!
 //! If you need to select over a dynamically created list of channel operations, use [`Select`]
@@ -303,18 +294,15 @@
 //!
 //! * [`after`] creates a channel that delivers a single message after a certain duration of time.
 //! * [`tick`] creates a channel that delivers messages periodically.
-//! * [`never`] creates a channel that never delivers messages.
+//! * [`never`](never()) creates a channel that never delivers messages.
 //!
 //! These channels are very efficient because messages get lazily generated on receive operations.
 //!
 //! An example that prints elapsed time every 50 milliseconds for the duration of 1 second:
 //!
 //! ```
-//! # #[macro_use]
-//! # extern crate crossbeam_channel;
-//! # fn main() {
 //! use std::time::{Duration, Instant};
-//! use crossbeam_channel::{after, tick};
+//! use crossbeam_channel::{after, select, tick};
 //!
 //! let start = Instant::now();
 //! let ticker = tick(Duration::from_millis(50));
@@ -326,54 +314,62 @@
 //!         recv(timeout) -> _ => break,
 //!     }
 //! }
-//! # }
 //! ```
 //!
-//! [`std::sync::mpsc`]: https://doc.rust-lang.org/std/sync/mpsc/index.html
-//! [`unbounded`]: fn.unbounded.html
-//! [`bounded`]: fn.bounded.html
-//! [`after`]: fn.after.html
-//! [`tick`]: fn.tick.html
-//! [`never`]: fn.never.html
-//! [`send`]: struct.Sender.html#method.send
-//! [`recv`]: struct.Receiver.html#method.recv
-//! [`iter`]: struct.Receiver.html#method.iter
-//! [`try_iter`]: struct.Receiver.html#method.try_iter
-//! [`select!`]: macro.select.html
-//! [`Select`]: struct.Select.html
-//! [`Sender`]: struct.Sender.html
-//! [`Receiver`]: struct.Receiver.html
+//! [`send`]: Sender::send
+//! [`recv`]: Receiver::recv
+//! [`iter`]: Receiver::iter
+//! [`try_iter`]: Receiver::try_iter
 
-#![warn(missing_docs)]
-#![warn(missing_debug_implementations)]
-
-extern crate crossbeam_utils;
-extern crate maybe_uninit;
+#![doc(test(
+    no_crate_inject,
+    attr(
+        deny(warnings, rust_2018_idioms),
+        allow(dead_code, unused_assignments, unused_variables)
+    )
+))]
+#![warn(
+    missing_docs,
+    missing_debug_implementations,
+    rust_2018_idioms,
+    unreachable_pub
+)]
+#![cfg_attr(not(feature = "std"), no_std)]
 
+#[cfg(feature = "std")]
 mod channel;
+#[cfg(feature = "std")]
 mod context;
+#[cfg(feature = "std")]
 mod counter;
+#[cfg(feature = "std")]
 mod err;
+#[cfg(feature = "std")]
 mod flavors;
+#[cfg(feature = "std")]
 mod select;
+#[cfg(feature = "std")]
 mod select_macro;
+#[cfg(feature = "std")]
 mod utils;
+#[cfg(feature = "std")]
 mod waker;
 
 /// Crate internals used by the `select!` macro.
 #[doc(hidden)]
+#[cfg(feature = "std")]
 pub mod internal {
-    pub use select::SelectHandle;
-    pub use select::{select, select_timeout, try_select};
+    pub use crate::select::{select, select_timeout, try_select, SelectHandle};
 }
 
-pub use channel::{after, never, tick};
-pub use channel::{bounded, unbounded};
-pub use channel::{IntoIter, Iter, TryIter};
-pub use channel::{Receiver, Sender};
-
-pub use select::{Select, SelectedOperation};
-
-pub use err::{ReadyTimeoutError, SelectTimeoutError, TryReadyError, TrySelectError};
-pub use err::{RecvError, RecvTimeoutError, TryRecvError};
-pub use err::{SendError, SendTimeoutError, TrySendError};
+#[cfg(feature = "std")]
+pub use crate::{
+    channel::{
+        after, at, bounded, never, tick, unbounded, IntoIter, Iter, Receiver, Sender, TryIter,
+    },
+    err::{
+        ReadyTimeoutError, RecvError, RecvTimeoutError, SelectTimeoutError, SendError,
+        SendTimeoutError, TryReadyError, TryRecvError, TrySelectError, TrySendError,
+    },
+    select::{Select, SelectedOperation},
+};
